#include <algorithm>
#include <cstdint>
#include <cstdlib>
#include <iostream>

using namespace std;

#define TYPE            uint64_t
#define TYPE_SIZE       (64)
//#define MAX_SIZE        (1000000)
#define TYPE_SIZE_POW2  (6)

uint8_t fast_popcount_mem[65536];

void fast_popcount_init()
{
    for(uint32_t i=0; i<65536; i++)
        fast_popcount_mem[i]=__builtin_popcount(i);
}

uint8_t fast_popcountll(uint64_t x)
{
    return fast_popcount_mem[(x>> 0ULL)&(0xFFFFULL)] +
           fast_popcount_mem[(x>>16ULL)&(0xFFFFULL)] +
           fast_popcount_mem[(x>>32ULL)&(0xFFFFULL)] +
           fast_popcount_mem[(x>>48ULL)&(0xFFFFULL)];
}

template <size_t ms>
class my_bitset
{
public:
    TYPE b[(ms/TYPE_SIZE)+1];
    size_t bs=0;

    bool get(size_t ind)
    {
        size_t ap=(ind>>TYPE_SIZE_POW2);
        uint8_t sp=ind&((1ULL<<TYPE_SIZE_POW2)-1);
        TYPE tmp=b[ap];
        tmp>>=sp;
        tmp&=1ULL;
        return (bool)tmp;
    }

    size_t count()
    {
        return bs;
    }

    void set(size_t ind, bool val)
    {
        size_t ap=(ind>>TYPE_SIZE_POW2);
        uint8_t sp=ind&((1ULL<<TYPE_SIZE_POW2)-1);

        //cout<<"AP: "<<ap<<endl;
        //cout<<"SP: "<<(short)sp<<endl;

        TYPE tmp=b[ap];

        //cout<<"FAK3: "<<ind<<' '<<tmp<<' '<<(1ULL<<sp)<<endl;

        if(tmp&(1ULL<<sp))
            bs--;
        tmp&= (~(1ULL<<sp));

        //cout<<"TMP: "<<tmp<<endl;
        //cout<<"ASDDSA: "<<val<<' '<<(short)sp<<' '<<(val<<sp)<<endl;
        tmp|=(((TYPE)val)<<sp);
        //cout<<"TMP: "<<tmp<<endl;

        if(val)
        {
            //cout<<"FAK: "<<bs<<endl;
            bs++;
            //cout<<"FAK2: "<<bs<<endl;
        }

        b[ap]=tmp;
    }


    my_bitset& operator++()
    {
        bool carry=0;
        size_t i=0;
        do
        {
            bs-=(size_t)fast_popcountll(b[i]);//bs-=__builtin_popcountll(b[i]);
            b[i]++;
            bs+=(size_t)fast_popcountll(b[i]);//bs+=__builtin_popcountll(b[i]);

            if(b[i]==0)
                carry=1;
            else
                carry=0;

            i++;
        }while(carry);
    }

};


//#define NMAX 1000008
#define NMAX 1000000008

typedef my_bitset<NMAX> bitnum_t;


uint32_t n;
bitnum_t a;

void test()
{
    /*
    cout<<a.count()<<endl;
    cout<<a.get(1)<<endl;
    a.set(1, 1);
    a.set(63, 1);
    a.set(64, 1);
    cout<<a.count()<<endl;
    cout<<a.get(1)<<endl;
    cout<<a.get(63)<<endl;
    cout<<a.get(64)<<endl;
    cout<<a.b[0]<<endl;
    cout<<a.b[1]<<endl;

    cout<<"NEW:"<<endl;
    a.set(1, 1);
    a.set(63, 0);
    a.set(64, 0);
    cout<<a.count()<<endl;
    cout<<a.get(1)<<endl;
    cout<<a.get(63)<<endl;
    cout<<a.get(64)<<endl;
    cout<<a.b[0]<<endl;
    cout<<a.b[1]<<endl;
    */


    /*
    for(uint32_t i=0; i<=64; i++)
        a.set(i, 1);
    cout<<"Count: "<<endl;
    cout<<a.count()<<endl;
    cout<<a.b[0]<<endl;
    cout<<a.b[1]<<endl;
    ++a;
    cout<<"Count: "<<endl;
    cout<<a.count()<<endl;
    cout<<a.b[0]<<endl;
    cout<<a.b[1]<<endl;
    ++a;
    cout<<"Count: "<<endl;
    cout<<a.count()<<endl;
    cout<<a.b[0]<<endl;
    cout<<a.b[1]<<endl;
    */

    /*
    for(uint32_t i=0; i<5; i++)
    {
        ++a;
        cout<<"Count: "<<endl;
        cout<<a.count()<<endl;
        cout<<a.b[0]<<endl;
    }
    */
}

void init()
{
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);

    fast_popcount_init();

    //cout<<(short)fast_popcountll(6723986700ULL)<<endl;

    cin>>n;
    if(n>=NMAX)
        exit(0);
    bool t=true;
    for(int32_t i=(int32_t)n-1; i>=0; i--)
    {
        a.set(i, t);//a[i]=t;
        t=!t;
    }

    //cout<<a.to_string()<<endl;
}

void solve()
{
    //TODO: check smaller n
    for(uint32_t i=1; i<=n+10; i++)
    {
        ++a;
        if(a.count() == i)
        {
            cout<<i<<endl;
            return;
        }
    }

    cout<<0<<endl;
}

int main()
{
    init();
    solve();


    return 0;
}
