#include <bits/stdc++.h>

const int32_t MAX_N = 1e5;

struct Vertex {
	bool vis;
	int32_t comp;
	std::vector< std::pair< int32_t, int32_t > > v, revV;
};

struct Event {
	int32_t x, type, i, j;

	Event() {}
	Event(int32_t _x, int32_t _type, int32_t _i, int32_t _j) : x(_x), type(_type), i(_i), j(_j) {}

	bool operator< (const Event &o) const {
		if(x != o.x) {
			return x < o.x;
		}
		else {
			return type < o.type;
		}
	}
};
	
int32_t n, a[MAX_N + 5], b[MAX_N + 5], c[MAX_N + 5], d[MAX_N + 5], ans[MAX_N + 5];
Vertex g[MAX_N + 5][2];

bool do_intersect(int32_t l1, int32_t r1, int32_t l2, int32_t r2) {
	if(l2 >= l1 && l2 <= r1) {
		return true;
	}
	if(r2 >= l1 && r2 <= r1) {
		return true;
	}
	if(l1 >= l2 && l1 <= r2) {
		return true;
	}
	if(r1 >= l2 && r1 <= r2) {
		return true;
	}

	return false;
}

void add_edge(int32_t x, int32_t i, int32_t y, int32_t j) {
	g[x][i].v.push_back({ y, j });
	g[y][j].revV.push_back({ x, i });
}

void build_graph() {
	std::vector< Event > evs;
	for(int32_t i = 0; i < n; i++) {
		evs.push_back(Event(a[i], 0, i, 0));
		evs.push_back(Event(b[i], 1, i, 0));
		evs.push_back(Event(c[i], 0, i, 1));
		evs.push_back(Event(d[i], 1, i, 1));
	}
	std::sort(evs.begin(), evs.end());
	
	std::set< std::pair< int32_t, int32_t > > active;
	for(auto &x : evs) {
		if(x.type == 0) {
			for(auto &y : active) {
				add_edge(y.first, y.second, x.i, 1 - x.j);
				add_edge(x.i, x.j, y.first, 1 - y.second);
			}

			active.insert({ x.i, x.j });
		}
		else {
			active.erase({ x.i, x.j });
		}
	}
}

void dfs(int32_t i, int32_t j, std::stack< std::pair< int32_t, int32_t > > &st) {
	g[i][j].vis = true;
	
	for(auto &x : g[i][j].v) {
		if(!g[x.first][x.second].vis) {
			dfs(x.first, x.second, st);
		}
	}

	st.push({ i, j });
}

void dfs_rev(int32_t i, int32_t j, int32_t comp) {
	g[i][j].comp = comp;

	for(auto &x : g[i][j].revV) {
		if(g[x.first][x.second].comp == 0) {
			dfs_rev(x.first, x.second, comp);
		}
	}
}

void compute_sccs() {
	std::stack< std::pair< int32_t, int32_t > > st;
	for(int32_t i = 0; i < n; i++) {
		for(int32_t j = 0; j < 2; j++) {
			if(!g[i][j].vis) {
				dfs(i, j, st);
			}
		}
	}
	
	int32_t comp = 1;
	while(!st.empty()) {
		auto x = st.top();
		st.pop();

		if(g[x.first][x.second].comp == 0) {
			dfs_rev(x.first, x.second, comp);
			comp++;
		}
	}
}

bool check_2sat() {
	compute_sccs();	

	for(int32_t i = 0; i < n; i++) {
		if(g[i][0].comp == g[i][1].comp) {
			return false;
		}
	}

	return true;
}

void compute_ans() {
	std::stack< std::pair< int32_t, int32_t > > st;

	for(int32_t i = 0; i < n; i++) {
		for(int32_t j = 0; j < 2; j++) {
			g[i][j].vis = false;
		}
	}

	for(int32_t i = 0; i < n; i++) {
		for(int32_t j = 0; j < 2; j++) {
			if(!g[i][j].vis) {
				dfs(i, j, st);
			}
		}
	}

	std::stack< std::pair< int32_t, int32_t > > stRev;
	while(!st.empty()) {
		stRev.push(st.top());
		st.pop();
	}

	while(!stRev.empty()) {
		auto x = stRev.top();
		stRev.pop();

		if(ans[x.first] == 0) {
			ans[x.first] = x.second + 1;
		}
	}
}

int main() {
	std::ios_base::sync_with_stdio(false);
	std::cin.tie(nullptr);

	std::cin >> n;

	for(int32_t i = 0; i < n; i++) {
		std::cin >> a[i] >> b[i] >> c[i] >> d[i];		
	}

	build_graph();

	if(check_2sat()) {
		std::cout << "Yes" << '\n';
		compute_ans();

		for(int32_t i = 0; i < n; i++) {
			std::cout << ans[i] << '\n';
		}
	}
	else {
		std::cout << "No" << '\n';
	}
}
