#include<iostream>
#include<cstring>
#include<vector>
#include<queue>
#include<map>
#include<set>
#include<algorithm>

using namespace std;

const int MAXN = 2e4 + 5;

struct singer
{
    pair <int, int> a, b;
    int index;
};

struct edge
{
    int v, edgeInd;
};

int n;
singer s[MAXN];

int codeNum = n+1;
map <int, int> code;

int dist[MAXN];
vector <int> cap;
int startInd[MAXN];
vector <edge> graph[MAXN];

int answer[MAXN];
int S = 20001, T = 20002;

void addEdge(int u, int v)
{
    //cout << u << " -> " << v << '\n';

    cap.push_back(1);
    cap.push_back(0);

    graph[u].push_back({v, cap.size()-2});
    graph[v].push_back({u, cap.size()-1});
}

void BFS(int x)
{
    queue <int> q;
    memset(dist, 0, sizeof(dist));

    q.push(x);
    dist[x] = 1;

    while(q.empty()==false)
    {
        x = q.front();
        q.pop();

        for(edge e: graph[x])
        {
            if(dist[e.v]==0 && cap[e.edgeInd]>0)
            {
                dist[e.v] = dist[x] + 1;
                q.push(e.v);
            }
        }
    }
}

int DFS(int x, int minVal)
{
    if(x==T) return minVal;

    for(int i = startInd[x];i<graph[x].size();i++)
    {
        edge e = graph[x][i];
        if(dist[e.v]==dist[x]+1 && cap[e.edgeInd]>0)
        {
            int flow = DFS(e.v, min(minVal, cap[e.edgeInd]));

            if(flow!=0)
            {
                cap[e.edgeInd] -= flow;
                cap[e.edgeInd^1] += flow;

                return flow;
            }
        }

        //startInd[x]++;

    }

    return 0;
}

int Dinic()
{
    int flow = 0;

    while(true)
    {
        BFS(S);
        if(dist[T]==0) break;

        memset(startInd, 0, sizeof(startInd));
        while(true)
        {
            int add = DFS(S, MAXN);
            if(add==0) break;

            flow += add;
        }
    }

    return flow;
}

int compress(int x)
{
    if(code.count(x)==false)
    {
        code[x] = codeNum;
        codeNum++;

        return codeNum - 1;
    }

    return code[x];
}

void Init()
{
    set <int> values;
    for(int i = 0;i<n;i++)
    {
        values.insert(s[i].a.first);
        values.insert(s[i].b.first);
    }

    codeNum = n + 1;
    for(auto it = values.begin();it!=values.end();it++)
    {
        compress(*it);
    }

    for(int i = 0;i<n;i++)
    {
        s[i].a.first = compress(s[i].a.first);
        s[i].b.first = compress(s[i].b.first);
    }
}

void buildGraph()
{
    for(int i = 1;i<=n;i++)
    {
        addEdge(S, i);
    }
    for(int i = n+1;i<codeNum;i++)
    {
        addEdge(i, T);
    }

    for(int i = 0;i<n;i++)
    {
        addEdge(i+1, s[i].a.first);
        addEdge(i+1, s[i].b.first);
    }
}

int main()
{
    ios::sync_with_stdio(false);
    cin.tie(NULL);

    cin >> n;
    for(int i = 0;i<n;i++)
    {
        cin >> s[i].a.first >> s[i].a.second;
        cin >> s[i].b.first >> s[i].b.second;
        s[i].index = i;
    }

    Init();
    buildGraph();

    int matching = Dinic();
    if(matching<n)
    {
        cout << "No" << '\n';
        return 0;
    }

    for(int x = 1;x<=n;x++)
    {
        for(edge e: graph[x])
        {
            if(e.v==S) continue;
            if(cap[e.edgeInd]==0)
            {
                if(e.v-n==s[x-1].a.first) answer[x] = 1;
                else answer[x] = 2;
            }
        }
    }

    cout << "Yes" << '\n';
    for(int i = 1;i<=n;i++)
    {
        cout << answer[i] << '\n';
    }
}
/*
4
2 2 3 3
0 0 4 4
0 0 1 1
1 1 2 2
*/
