#include<iostream>
#include<vector>
#include<time.h>
#include<random>
#include<map>
#include<set>

using namespace std;

const int MAXN = 45;
const int inf = 1e9 + 5;

int n, m;
bool used[MAXN];
vector <pair <int, int>> bombs;
vector <pair <int, int>> presents;

int minSteps = MAXN;
vector <pair <int, pair <int, int>>> answer;

int codeNum = 1;
map <int, int> mp;
int invMp[MAXN];

int grid[MAXN][MAXN]; //0 -> empty, 1 -> bomb, 2 -> present
int pos2Present[MAXN][MAXN];

double start;

mt19937 rnd(69420);

int compress(int x)
{
    if(mp.count(x)==false)
    {
        mp[x] = codeNum;
        invMp[codeNum] = x;

        codeNum += 2;

        return codeNum - 2;
    }

    return mp[x];
}

void Init()
{
    set <int> s;
    for(pair <int, int> x: bombs)
    {
        s.insert(x.first);
        s.insert(x.second);
    }
    for(pair <int, int> x: presents)
    {
        s.insert(x.first);
        s.insert(x.second);
    }

    for(auto it = s.begin();it!=s.end();it++)
    {
        compress(*it);
    }

    for(pair <int, int> &x: bombs)
    {
        x.first = compress(x.first);
        x.second = compress(x.second);

        grid[x.first][x.second] = 1;
    }
    for(int i = 0;i<presents.size();i++)
    {
        pair <int, int> &x = presents[i];

        presents[i].first = compress(x.first);
        presents[i].second = compress(x.second);

        grid[x.first][x.second] = 2;
        pos2Present[x.first][x.second] = i;

        //cout << "grid " << x.first << " " << x.second << '\n';
    }
}

bool isReady()
{
    for(int i = 0;i<n;i++)
    {
        if(used[i]==false) return false;
    }

    return true;
}

void doAnswer()
{
    if(minSteps==MAXN)
    {
        cout << "No" << '\n';
    }

    cout << minSteps << '\n';
    for(pair <int, pair <int, int>> x: answer)
    {
        cout << x.first << " " << x.second.first << " " << x.second.second << '\n';
    }

    exit(0);
}

vector <pair <int, int>> doVertical(int x, int y)
{
    //cout << x << "%%%" << y << '\n';

    vector <pair <int, int>> v;
    for(int i = x;i<MAXN;i++)
    {
        if(grid[i][y]!=0)
        {
            if(grid[i][y]==2)
            {
                //cout << " --- " << i << " " << y << '\n';
                v.push_back({i, y});
            }

            break;
        }
    }
    for(int i = x;i>=0;i--)
    {
        if(grid[i][y]!=0)
        {
            if(grid[i][y]==2)
            {
                //cout << "  -*- " << i << " " << y << '\n';
                v.push_back({i, y});
            }

            break;
        }
    }

    return v;
}

vector <pair <int, int>> doHorizontal(int x, int y)
{
    vector <pair <int, int>> v;
    for(int i = y;i<MAXN;i++)
    {
        if(grid[x][i]!=0)
        {
            if(grid[x][i]==2)
            {
                v.push_back({x, i});
            }

            break;
        }
    }
    for(int i = y;i>=0;i--)
    {
        if(grid[x][i]!=0)
        {
            if(grid[x][i]==2)
            {
                v.push_back({x, i});
            }

            break;
        }
    }

    return v;
}

vector <pair <int, pair <int, int>>> path;
void bruteForce(int steps)
{
    if(isReady()==true)
    {
        if(steps<minSteps)
        {
            minSteps = steps;
            answer = path;
        }

        return;
    }

    if(double(clock()-start)/CLOCKS_PER_SEC > 0.9)
    {
        doAnswer();
    }

    for(int i = 0;i<presents.size();i++)
    {
        if(used[i]==true) continue;
        vector <pair <int, int>> v;

        //cout << i << " " << steps << '\n';

        //up
        if(rnd()%100<80)
        {
            path.push_back({0, {invMp[presents[i].first]-1, invMp[presents[i].second]}});

            v = doVertical(presents[i].first-1, presents[i].second);
            for(pair <int, int> x: v)
            {
                grid[x.first][x.second] = 0;
                used[ pos2Present[x.first][x.second] ] = true;
            }
            bruteForce(steps+1);
            for(pair <int, int> x: v)
            {
                grid[x.first][x.second] = 2;
                used[ pos2Present[x.first][x.second] ] = false;
            }

            path.pop_back();
        }

        //right
        if(rnd()%100<80)
        {
            path.push_back({1, {invMp[presents[i].first], invMp[presents[i].second]+1}});

            v = doHorizontal(presents[i].first, presents[i].second+1);
            for(pair <int, int> x: v)
            {
                grid[x.first][x.second] = 0;
                used[ pos2Present[x.first][x.second] ] = true;
            }
            bruteForce(steps+1);
            for(pair <int, int> x: v)
            {
                grid[x.first][x.second] = 2;
                used[ pos2Present[x.first][x.second] ] = false;
            }

            path.pop_back();
        }
    }
}

int main()
{
    ios::sync_with_stdio(false);
    cin.tie(NULL);

    cin >> n;
    for(int i = 0;i<n;i++)
    {
        int x, y;
        cin >> x >> y;

        presents.push_back({x, y});
    }

    start = clock();

    cin >> m;
    for(int i = 0;i<m;i++)
    {
        int x, y;
        cin >> x >> y;

        bombs.push_back({x, y});
    }

    Init();
    bruteForce(0);

    doAnswer();
}
/*
2
2 5
2 7
0
*/
