#include <bits/stdc++.h>

#pragma GCC optimize "-O3"

#define endl "\n"
#define trace(x) cerr << #x << " = " << x << endl

using namespace std;

class Graph {
private:
	class Edge {
	public:
		int from;
		int to;
		int flow;
		int cap;
		int rev;

		Edge(int from, int to, int flow, int cap, int rev) {
			this->from = from;
			this->to = to;
			this->flow = flow;
			this->cap = cap;
			this->rev = rev;
		}
	};

	vector<Edge> edges;
	vector<vector<int>> adjList;

	vector<int> level, head;

	bool bfs(int s, int t) {
		fill(this->level.begin(), this->level.end(), -1);
		fill(this->head.begin(), this->head.end(), 0);

		queue<int> q;
		this->level[s] = 0;
		q.emplace(s);

		while (!q.empty()) {
			int now = q.front();
			q.pop();

			for (int edgeIndex : this->adjList[now]) {
				if (this->edges[edgeIndex].flow < this->edges[edgeIndex].cap && this->level[this->edges[edgeIndex].to] == -1) {
					this->level[this->edges[edgeIndex].to] = this->level[now] + 1;
					q.emplace(this->edges[edgeIndex].to);
				}
			}
		}

		return this->level[t] != -1;
	}

	int sendFlow(int node, int target, int flow = (int)1e9) {
		if (node == target) {
			return flow;
		}

		for (int i = this->head[node]; i < (int)this->adjList[node].size(); i++) {
			Edge &edge = this->edges[this->adjList[node][i]];

			if (edge.flow == edge.cap || this->level[edge.to] != this->level[node] + 1) {
				this->head[node]++;
			}

			if (edge.flow < edge.cap && this->level[edge.to] == this->level[node] + 1) {
				int currFlow = this->sendFlow(edge.to, target, min(flow, edge.cap - edge.flow));

				edge.flow += currFlow;
				this->edges[this->adjList[edge.to][edge.rev]].flow -= currFlow;

				if (currFlow > 0) {
					return currFlow;
				}
			}
		}

		this->level[node] = (int)1e9;

		return 0;
	}

public:
	int maxMatching(int s, int t) {
		int answer = 0;
		while (this->bfs(s, t)) {
			while (int flow = this->sendFlow(s, t)) {
				answer += flow;
			}
		}

		return answer;
	}

	void init(int n) {
		this->adjList.resize(n + 1);
		this->head.resize(n + 1);
		this->level.resize(n + 1);
	}

	void addEdge(int u, int v) {
		this->edges.emplace_back(u, v, 0, 1, this->adjList[v].size());
		this->adjList[u].emplace_back(this->edges.size() - 1);

		this->edges.emplace_back(v, u, 0, 0, this->adjList[u].size() - 1);
		this->adjList[v].emplace_back(this->edges.size() - 1);
	}

	vector<pair<int, int>> getMatching() {
		vector<pair<int, int>> answer;
		for (auto &edge : this->edges) {
			if (edge.flow == edge.cap && edge.cap > 0) {
				answer.emplace_back(edge.from, edge.to);
			}
		}

		return move(answer);
	}
};

int n;
vector<pair<int, int>> people;
vector<int> points;

int getIndex(int x) {
	return lower_bound(points.begin(), points.end(), x) - points.begin();
}

Graph g;

int main() {
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);
	cout.tie(nullptr);

	cin >> n;

	people.resize(n + 1);
	for (int i = 1; i <= n; i++) {
		int si, ei, sj, ej;
		cin >> si >> ei >> sj >> ej;

		people[i] = {si, sj};

		points.emplace_back(si);
		points.emplace_back(sj);
	}

	sort(points.begin(), points.end());
	points.resize(distance(points.begin(), unique(points.begin(), points.end())));

	for (int i = 1; i <= n; i++) {
		people[i].first = getIndex(people[i].first);
		people[i].second = getIndex(people[i].second);
	}

	g.init(n + (int)points.size() + 1);

	for (int i = 1; i <= n; i++) {
		g.addEdge(0, i);

		g.addEdge(i, n + getIndex(people[i].first));
		g.addEdge(i, n + getIndex(people[i].second));
	}

	for (int i = n + 1; i <= n + (int)points.size(); i++) {
		g.addEdge(i, n + (int)points.size() + 1);
	}

	if (g.maxMatching(0, n + (int)points.size() + 1) < n) {
		cout << "No\n";

		return EXIT_SUCCESS;
	}

	cout << "Yes\n";

	vector<pair<int, int>> edges = g.getMatching();

	vector<int> answer(n + 1);

	for (auto &edge : edges) {
		if (edge.first > 0 && edge.second <= n + (int)points.size()) {
			if (people[edge.first].first == edge.second - n) {
				answer[edge.first] = 1;
			} else {
				answer[edge.first] = 2;
			}
		}
	}

	for (int i = 1; i <= n; i++) {
		cout << answer[i] << endl;
	}

	return EXIT_SUCCESS;
}