#include <cstdio>
#include <cstdlib>
#include <fstream>
#include <algorithm>
#include <vector>
#include <set>
#include <map>
#include <iostream>
#include <queue>
#include <stack>
#define ll long long


using namespace std;

struct MaxFlow {
    struct Edge {
        int to, flx, nxt;
    };

    vector <Edge> cur;
    vector <int> lvl, last, att;
    int n;

    inline void init(int _n) {
        n = _n;
        lvl.resize(n + 1), att.resize(n + 1, -1);
    }

    inline void addEdge(int x, int y, int c) {
        Edge e;
        e.to = y, e.flx = c, e.nxt = att[x];
        cur.push_back(e);
        att[x] = (int)(cur.size() - 1);

        e.to = x, e.flx = 0, e.nxt = att[y];
        cur.push_back(e);
        att[y] = (int)(cur.size() - 1);
    }

    inline bool bfs(int S, int D) {
        queue <int> Q;
        fill(lvl.begin(), lvl.end(), 0);

        Q.push(S);
        lvl[S] = 1;

        while(Q.size()) {
            int nod = Q.front();
            Q.pop();
            int pos = att[nod];
            while(pos != -1) {
                if(lvl[cur[pos].to] == 0 && cur[pos].flx > 0) {
                    lvl[cur[pos].to] = lvl[nod] + 1;
                    Q.push(cur[pos].to);
                }
                pos = cur[pos].nxt;
            }
        }
        return lvl[D] > 0;
    }

    int dfs(int S, int D, int mn) {
        if(S == D || mn == 0) return mn;

        while(last[S] != -1) {
            int pos = last[S];
            Edge &e = cur[pos];
            int f;

            if(lvl[e.to] == lvl[S] + 1 && (f = dfs(e.to, D, min(e.flx, mn))) != 0) {
                e.flx -= f;
                cur[pos ^ 1].flx += f;
                return f;
            }
            else {
                last[S] = e.nxt;
            }
        }

        return 0;
    }

    inline int getFlow(int S, int D) {
        int ans = 0;
        while(bfs(S, D)) {
            last = att;
            int f;
            while((f = dfs(S, D, 1e9)) != 0) {
                ans += f;
            }
        }
        return ans;
    }
};

map <int, int> mp;

inline int norm(vector <int> vals) {
    sort(vals.begin(), vals.end());
    vals.resize(unique(vals.begin(), vals.end()) - vals.begin());
    for(int i = 0; i < vals.size(); i++) {
        mp[vals[i]] = i + 1;
    }
    return vals.size();
}

int main() {
#ifdef HOME
    ifstream cin("A.in");
    ofstream cout("A.out");
#endif // HOME
    int i, n;
    ios::sync_with_stdio(false);
    cin.tie(0), cout.tie(0);

    cin >> n;

    vector <int> a(n), b(n), c(n), d(n);
    vector <int> vals;
    for(i = 0; i < n; i++) {
        cin >> a[i] >> b[i] >> c[i] >> d[i];
        b[i]++, d[i]++;
        vals.push_back(a[i]);
        vals.push_back(b[i]);
        vals.push_back(c[i]);
        vals.push_back(d[i]);
    }

    int sz = norm(vals);
    for(i = 0; i < n; i++) {
        a[i] = mp[a[i]], b[i] = mp[b[i]], c[i] = mp[c[i]], d[i] = mp[d[i]];
    }

    int S = n + sz + 1;
    int D = S + 1;
    MaxFlow net; net.init(D);

    for(i = 1; i <= n; i++) {
        net.addEdge(S, i, 1);
        net.addEdge(i, a[i - 1] + n, 1);
        net.addEdge(i, c[i - 1] + n, 1);
    }
    for(i = 1; i <= sz; i++) {
        net.addEdge(i + n, D, 1);
    }

    if(net.getFlow(S, D) != n) {
        cout << "No";
        return 0;
    }

    cout << "Yes\n";
    for(i = 1; i <= n; i++) {
        int pos = net.att[i];
        int ans = -1;
        while(pos != -1) {
            if(net.cur[pos].flx == 0 && net.cur[pos].to != S) {
                if(net.cur[pos].to == a[i - 1] + n) {
                    ans = 1;
                }
                else {
                    ans = 2;
                }
                break;
            }
            pos = net.cur[pos].nxt;
        }
        cout << ans << "\n";
    }

    return 0;
}
